@@ -9,6 +9,7 @@
 #' Fisher_exact_test_2x2(lampasona_2013)
 #' Fisher_exact_test_2x2(ritland_2007)
 #' @export
+#' @inheritSection chap4 Table orientation
 #' @return An object of the [contingencytables_result] class,
 #' basically a subclass of [base::list()]. Use the [utils::str()] function
 #' to see the specific elements returned.
@@ -64,7 +65,11 @@ test_statistic_fisher_exact_test_2x2 <- function(x11, x12, x21, x22, statistic)
   if (statistic == "hypergeometric") {
     # The hypergeometric distribution
     # Small values agree less with H0 than large values => "-" sign
-    T0 <- -dhyper(x11, x11 + x21, N - x11 - x21, x11 + x12)
+    # Using definitions from https://se.mathworks.com/help/stats/hygepdf.html
+    M <- N
+    K <- x11 + x21
+    N <- x11 + x12
+    T0 <- -dhyper(x = x11, m = N, n = M - N, k = K)
   } else if (statistic == "Pearson") {
     # Pearson's chi-squared statistic
     T0 <- (N * (x11 * x22 - x12 * x21)^2) / ((x11 + x12) * (x21 + x22) * (x11 + x21) * (x12 + x22))
