@@ -53,7 +53,7 @@ Kendalls_tau_b_rxc_bca <- function(n, nboot = 10000, alpha = 0.05) {
 
   return(
     contingencytables_result(
-      list(tau_b = tau_b, L = L, U = U),
+      list("tau_b" = tau_b, "lower" = L, "upper" = U),
       sprintf(
         "Kendalls tau-b w / BCa bootstrap CI: tau-b = %7.4f (%g%% CI %7.4f to %7.4f)",
         tau_b, 100 * (1 - alpha), L, U
