@@ -30,7 +30,7 @@ McNemarBowker_test_paired_cxc <- function(n) {
 
   return(
     contingencytables_result(
-      list(P = P, T = T0, df = df),
+      list("Pvalue" = P, "T" = T0, "df" = df),
       sprintf("The McNemar-Bowker test for symmetry: P = %8.6f, T0 = %6.3f (df=%g)", P, T0, df)
     )
   )
