@@ -55,7 +55,7 @@ Wald_CI_diff_CC_paired_2x2 <- function(n, alpha = 0.05) {
 
   return(
     contingencytables_result(
-      list(L = L, U = U, estimate = estimate), printresults
+      list("lower" = L, "upper" = U, "estimate" = estimate), printresults
     )
   )
 }
