@@ -66,7 +66,7 @@ Wald_test_and_CI_marginal_mean_scores_paired_cxc <- function(
 
   return(
     contingencytables_result(
-      list(P = P, Z_Wald = Z_Wald, L = L, U = U, estimate = estimate),
+      list("Pvalue" = P, "Z" = Z_Wald, "lower" = L, "upper" = U, "estimate" = estimate),
       printresults
     )
   )
