@@ -26,6 +26,10 @@ test_that("Chapter 8 functions basically work", {
     object = print(BonettPrice_hybrid_Wilson_score_CI_paired_2x2(cavo_2012)),
     regexp = "estimate = 0.8667 \\(95% CI 0.7579 to 0.9910\\)"
   )
+  expect_output(
+    object = print(BonettPrice_hybrid_Wilson_score_CI_paired_2x2(cavo_2012 * 0)),
+    regexp = "Wilson score CI: estimate =    NaN \\(95% CI 0.0000 to    Inf\\)"
+  )
   expect_output(
     object = print(BonettPrice_hybrid_Wilson_score_CI_CC_paired_2x2(matrix(c(0, 0, 0, 2), 2))),
     regexp = "CI w / CC: estimate =    NaN \\(95% CI 0.0000 to    Inf\\)"
@@ -68,6 +72,10 @@ test_that("Chapter 8 functions basically work", {
     object = print(McNemar_exact_unconditional_test_paired_2x2(n_short)),
     regexp = "The McNemar exact unconditional test: P = 0.542071"
   )
+  expect_output(
+    object = print(McNemar_exact_unconditional_test_paired_2x2(tea  * 0)),
+    regexp = "The McNemar exact unconditional test: P = 1.000000"
+  )
   expect_output(
     object = print(McNemar_midP_test_paired_2x2(cavo_2012)),
     regexp = "The McNemar mid-P test: P = 0.034690"
@@ -76,10 +84,28 @@ test_that("Chapter 8 functions basically work", {
     object = print(Tang_asymptotic_score_CI_paired_2x2(cavo_2012)),
     regexp = "estimate = 0.8667 \\(95% CI 0.7476 to 0.9876\\)"
   )
+  expect_output(
+    object = print(
+      Tang_asymptotic_score_CI_paired_2x2(matrix(c(1, 2, NA, 4), 2))
+    ),
+    regexp = "score CI: estimate =     NA \\(95% CI 0.0000 to    Inf\\)"
+  )
   expect_output(
     object = print(Tango_asymptotic_score_CI_paired_2x2(cavo_2012)),
     regexp = "score CI: estimate = -0.0621 \\(95% CI -0.1240 to -0.0054\\)"
   )
+  expect_output(
+    object = print(
+      Tango_asymptotic_score_CI_paired_2x2(matrix(c(0, 0, 3, 0), 2))
+    ),
+    regexp = "Tango asymptotic .+ 1.0000 \\(95% CI -0.1230 to 1.0000\\)"
+  )
+  expect_output(
+    object = print(
+      Tango_asymptotic_score_CI_paired_2x2(matrix(c(0, 3, 0, 0), 2))
+    ),
+    regexp = "Tango asymptotic .+ -1.0000 \\(95% CI -1.0000 to 0.1230\\)"
+  )
   expect_output(
     object = print(Wald_CI_diff_paired_2x2(cavo_2012)),
     regexp = "The Wald CI: estimate = -0.0621 \\(95% CI -0.1184 to -0.0058\\)"
@@ -88,6 +114,10 @@ test_that("Chapter 8 functions basically work", {
     object = print(Wald_CI_diff_CC_paired_2x2(cavo_2012)),
     regexp = "estimate = -0.0621 \\(95% CI -0.1186 to -0.0057\\)"
   )
+  expect_output(
+    object = print(Wald_CI_diff_CC_paired_2x2(bentur_2009 * NA)),
+    regexp = "Wald CI with continuity correction.+NA \\(95% CI.+NA to.+NA\\)"
+  )
   expect_output(
     object = print(Wald_CI_AgrestiMin_paired_2x2(cavo_2012)),
     regexp = "adjustment: estimate = -0.0621 \\(95% CI -0.1182 to -0.0045\\)"
@@ -96,10 +126,22 @@ test_that("Chapter 8 functions basically work", {
     object = print(MOVER_Wilson_score_CI_paired_2x2(cavo_2012)),
     regexp = "estimate = 0.8667 \\(95% CI 0.7592 to 0.9866\\)"
   )
+  expect_output(
+    object = print(MOVER_Wilson_score_CI_paired_2x2(bentur_2009 * 0)),
+    regexp = "Wilson score CI: estimate =    NaN \\(95% CI    NaN to    Inf\\)"
+  )
   expect_output(
     object = print(Newcombe_square_and_add_CI_paired_2x2(cavo_2012)),
     regexp = "estimate = -0.0621 \\(95% CI -0.1186 to -0.0046\\)"
   )
+  expect_output(
+    object = print(Newcombe_square_and_add_CI_paired_2x2(matrix(c(1, 0, 0, 1), 2))),
+    regexp = "Newcombe square-and-add .+  0.0000 \\(95% CI -0.5734 to  0.5734\\)"
+  )
+  expect_output(
+    object = print(Newcombe_square_and_add_CI_paired_2x2(matrix(c(0, 0, 0, 0), 2))),
+    regexp = "Newcombe square-and-add .+ NaN \\(95% CI     NaN to     NaN\\)"
+  )
   expect_output(
     object = print(Transformed_Wilson_score_CI_paired_2x2(cavo_2012)),
     regexp = "0.3750 \\(95% CI 0.1514 to 0.9287\\)"
@@ -128,6 +170,10 @@ test_that("Chapter 8 functions basically work", {
     object = print(Wald_CI_OR_Laplace_paired_2x2(ezra_2010)),
     regexp = "adjustment: estimate = 12.5000 \\(95% CI 2.6232 to 28.6333\\)"
   )
+  expect_output(
+    object = print(Wald_CI_OR_Laplace_paired_2x2(matrix(c(1, NA, 2, 3), 2))),
+    regexp = "adjustment: estimate =     NA \\(95% CI 0.0000 to    Inf\\)"
+  )
   expect_output(
     object = print(Transformed_Clopper_Pearson_exact_CI_paired_2x2(ezra_2010)),
     regexp = "estimate = 12.5000 \\(95% CI 3.1169 to 108.8892\\)"
