@@ -13,7 +13,7 @@ test_that("Printing method works for pvalue_df_estimate_statname", {
   expect_invisible(tmp <- Bhapkar_test_paired_cxc(peterson_2007))
   expect_silent(tmp)
   expect_output(print(tmp), "The Bhapkar test for marginal homogenity")
-  expect_output(print(tmp, as_list = TRUE), "pvalue")
+  expect_output(print(tmp, as_list = TRUE), "Pvalue")
   expect_length(tmp, 3)
 })
 
@@ -22,8 +22,6 @@ test_that("Printing method works for pvalue", {
   expect_invisible(tmp <- Blaker_exact_test_1x2(13, 16, 0.5))
   expect_silent(tmp)
   expect_output(print(tmp), "The Blaker exact test")
-  expect_output(print(tmp, as_list = TRUE), "pvalue")
+  expect_output(print(tmp, as_list = TRUE), "Pvalue")
   expect_length(tmp, 1)
 })
-
-# TODO: add other print methods for contingencytables_singletest
