@@ -117,6 +117,10 @@ test_that("Invalid arguments are picked up", {
     Exact_unconditional_test_2x2(tea, "LER"),
     "Should be Pearson, LR, unpooled, Fisher."
   )
+  expect_error(
+    Exact_unconditional_test_2x2(matrix(c(0, 0, 5, 5), 2), "Pearson"),
+    "Consider using either the LR, unpooled, or Fisher statistic instead."
+  )
   expect_error(
     Fisher_exact_test_2x2(tea, "Fisher"),
     "Should be Pearson, hypergeometric, LR."
